hupili's Python utilities
=========================

Why making a utility repo?
--------------------------

- Reduce repeated works.
- Code snippets and notes are not enough to memorize things.
- Make it easier to synchronize between my machines.

Why not call it "utility", "utils", "pyutils"?
----------------------------------------------

- Some of the names are taken, including old repos and new repos.
- I believe different people have different collections.
  I don't want to mess the public index.
  Probably ``utility`` will be used later for more important purpose?

Why the module files are prefixed with "pl"?
--------------------------------------------

- Some names are taken by the standard libs
  and my editor's plugin complains. e.g. ``time``.
